<?php

declare(strict_types=1);

namespace apexl\Io\modules\cron;

use apexl\Io\includes\Module;
use apexl\Io\modules\cron\Hook\ConsoleCommands;
use app\vendor\apexl\io\src\Io\interfaces\ProvidesHooksInterface;

class cronModule extends Module implements ProvidesHooksInterface
{
    public final const string HOOK__REGISTER_CRON_TASK = 'cron.register_cron_tasks';

    public function hooks(): array
    {
        return [
            ConsoleCommands::class,
        ];
    }
}
